# Table Collection

Table Collection commands are used to create dynamic table types and tables.

## Creat table collections for Assembly

```{eval-rst}
.. autoclass:: abaqus.TableCollection.TableCollectionAssembly.TableCollectionAssembly
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

## Creat table collections for Model

```{eval-rst}
.. autoclass:: abaqus.TableCollection.TableCollectionModel.TableCollectionModel
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

## Other Classes

```{eval-rst}

.. toggle::

    .. autoclass:: abaqus.TableCollection.ActivateElements.ActivateElements
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.TableCollection.DataTable.DataTable
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.TableCollection.DataTableArray.DataTableArray
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.TableCollection.ElementProgressiveActivation.ElementProgressiveActivation
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.TableCollection.EventSeries.EventSeries
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.TableCollection.EventSeriesData.EventSeriesData
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.TableCollection.EventSeriesType.EventSeriesType
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.TableCollection.ParameterColumn.ParameterColumn
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.TableCollection.ParameterColumnArray.ParameterColumnArray
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.TableCollection.ParameterTable.ParameterTable
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.TableCollection.PropertyTable.PropertyTable
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.TableCollection.PropertyTableData.PropertyTableData
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.TableCollection.TableCollection.TableCollection
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::
```
